/*
 *  Database class for DMAP sharing
 *
 * Copyright (c) 2008 W. Michael Petullo <new@flyn.org>
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _DMAPD_DMAP_DB_H
#define _DMAPD_DMAP_DB_H

#include <libdmapsharing/dmap.h>

G_BEGIN_DECLS

#define TYPE_DMAPD_DMAP_DB           (dmapd_dmap_db_get_type ())
#define DMAPD_DMAP_DB(o)             (G_TYPE_CHECK_INSTANCE_CAST ((o), \
                                      TYPE_DMAPD_DMAP_DB, \
                                      DmapdDmapDb))
#define DMAPD_DMAP_DB_CLASS(k)       (G_TYPE_CHECK_CLASS_CAST((k), \
                                      TYPE_DMAPD_DMAP_DB, \
                                      DmapdDmapDbClass))
#define IS_DMAPD_DMAP_DB(o)          (G_TYPE_CHECK_INSTANCE_TYPE ((o), \
                                      TYPE_DMAPD_DMAP_DB))
#define IS_DMAPD_DMAP_DB_CLASS (k)   (G_TYPE_CHECK_CLASS_TYPE ((k), \
                                      TYPE_DMAPD_DMAP_DB_CLASS))
#define DMAPD_DMAP_DB_GET_CLASS(o)   (G_TYPE_INSTANCE_GET_CLASS ((o), \
                                      TYPE_DMAPD_DMAP_DB, \
                                      DmapdDmapDbClass))
#define DMAPD_DMAP_DB_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), \
                                      TYPE_DMAPD_DMAP_DB, \
                                      DmapdDmapDbPrivate))

typedef struct DmapdDmapDbPrivate DmapdDmapDbPrivate;

typedef struct {
	GObject parent;
	DmapdDmapDbPrivate *priv;
} DmapdDmapDb;

typedef struct {
	GObjectClass parent;

	guint (*add)                   (DmapDb *db, DmapRecord *record, GError **error);
	guint (*add_with_id)           (DmapDb *db,
					DmapRecord *record,
					guint id,
	                                GError **error);
	guint (*add_path)              (DmapDb *db, const gchar *path, GError **error);
	DmapRecord *(*lookup_by_id)    (const DmapDb *db, guint id);
	guint (*lookup_id_by_location) (const DmapDb *db,
					const gchar *location);
	void (*foreach)                (const DmapDb *db,
					DmapIdRecordFunc func,
					gpointer data);
	gint64 (*count)                (const DmapDb *db);
} DmapdDmapDbClass;

GType dmapd_dmap_db_get_type (void);

#endif /* __DMAPD_DMAP_DB */

G_END_DECLS
